`runApp_startProject` will open a viewer window that will allow you
to run startProject as a local shiny App.
See also
startProject for details on inputs.
Author
Rocio Lopez, lopezr@ccf.org
`runApp_startProject` will open a viewer window that will allow you
to run startProject as a local shiny App.
startProject for details on inputs.
Rocio Lopez, lopezr@ccf.org